@@ -6,7 +6,7 @@ import os, sys, ast, json, glob, platform, subprocess, random, requests, urllib,
 
 # inc imports.
 import cl1, netw0rk, syst3m, ssht00ls
-from fil3s import Files, Formats
+from fil3s import *
 from r3sponse import r3sponse
 
 # source.	
@@ -17,6 +17,9 @@ OS = syst3m.defaults.operating_system(supported=["linux", "macos"])
 LOG_LEVEL = syst3m.defaults.log_level(default=0)
 #syst3m.defaults.alias(alias=ALIAS, executable=SOURCE_PATH)
 
+# version.
+version = Files.load(f"{SOURCE_PATH}/.version")
+
 # network info.
 NETWORK_INFO = netw0rk.network.info()
 if not NETWORK_INFO["success"]: raise ValueError(NETWORK_INFO["error"])
